-- Copyright: 2022 Everblush
-- License: MIT
-- Source: https://github.com/Everblush/lite-xl

local style = require "core.style"
local common = require "core.common"

style.background = { common.color "#141b1e" }
style.background2 = { common.color "#1e2528" }
style.background3 = { common.color "#2d3437" }
style.text = { common.color "#dadada" }
style.caret = { common.color "#dadada" }
style.accent = { common.color "#67b0e8" }
style.dim = { common.color "#bdc3c2" }
style.divider = { common.color "#232a2d" }
style.selection = { common.color "#232a2d" }
style.line_number = { common.color "#bdc3c2" }
style.line_number2 = { common.color "#a9afae" }
style.line_highlight = { common.color "#2d3437" }
style.scrollbar = { common.color "#bab3e5" }
style.scrollbar2 = { common.color "#c4bdef" }

style.syntax["normal"] = { common.color "#b3b9b8" }
style.syntax["symbol"] = { common.color "#b3b9b8" }
style.syntax["comment"] = { common.color "#404749" }
style.syntax["keyword"] = { common.color "#67b0e8" }
style.syntax["keyword2"] = { common.color "#6cbfbf" }
style.syntax["number"] = { common.color "#dadada" }
style.syntax["literal"] = { common.color "#e5c76b" }
style.syntax["string"] = { common.color "#75cf72" }
style.syntax["operator"] = { common.color "#bab3e5" }
style.syntax["function"] = { common.color "#e57474" }
